'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _state = require('./state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-console */

class Rpc {

  constructor() {
    this._history = [];
  }

  get history() {
    return this._history;
  }

  _addHistory(command) {
    // Remove earlier occurance of identical command
    const earlierIndex = this._history.findIndex(item => item === command);
    if (earlierIndex >= 0) {
      this._history.splice(earlierIndex, 1);
    }

    // Add command to top of history
    this._history.push(command);
  }

  request(command, remember = false) {
    if (remember) {
      this._addHistory(command);
    }

    const commandComponents = command.split(' ');
    const [method, ...params] = commandComponents;

    // return new pending promise
    let responseData = '';
    return new Promise((resolve, reject) => {

      const rpcRequest = {
        jsonrpc: '1.0',
        id: `node-manager${new Date().toISOString()}`,
        method
      };
      if (params.length) {
        rpcRequest.params = params;
      }
      const postData = JSON.stringify(rpcRequest);

      const reqOptions = {
        hostname: _state2.default.connection.host,
        port: _state2.default.connection.port,
        method: 'POST',
        headers: {
          'Content-Type': 'application/json-rpc',
          'Content-Length': Buffer.byteLength(postData)
        }
      };
      if (_state2.default.connection.auth) {
        reqOptions.auth = _state2.default.connection.auth;
      }

      const req = _http2.default.request(reqOptions, res => {
        res.setEncoding('utf8');
        res.on('data', chunk => {
          responseData = responseData.concat(chunk);
        });
        res.on('end', () => {
          if (responseData) {
            try {
              // Probably JSON response
              const jsonResponse = JSON.parse(responseData);
              if (jsonResponse.error) {
                if (jsonResponse.error.message) {
                  reject(new Error(jsonResponse.error.message));
                } else {
                  reject(new Error(`bitcoind error: ${JSON.stringify(jsonResponse.error)}`));
                }
              } else {
                resolve(jsonResponse.result);
              }
            } catch (err) {
              // Not a JSON response - probably just an error message in plaintext
              reject(new Error(`Error: ${responseData}`));
            }
          } else if (res.statusCode !== 200) {
            reject(new Error(`Error: ${res.statusCode}: ${res.statusMessage}`));
          } else {
            resolve('');
          }
        });
      });

      req.on('error', err => {
        reject(err);
      });

      // write data to request body
      req.write(postData);
      req.end();
    });
  }
}
exports.default = Rpc;