'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuOption = require('tooey/lib/MenuOption');

var _MenuOption2 = _interopRequireDefault(_MenuOption);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Network = require('cashlib/lib/Network');

var _Network2 = _interopRequireDefault(_Network);

var _Connection = require('../../model/Connection');

var _Connection2 = _interopRequireDefault(_Connection);

var _MainMenu = require('./MainMenu');

var _MainMenu2 = _interopRequireDefault(_MainMenu);

var _NetworkSelection = require('./NetworkSelection');

var _NetworkSelection2 = _interopRequireDefault(_NetworkSelection);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class ConnectionHistory extends _ViewBase2.default {

  constructor() {
    super('Recent Connections');

    this._connectOption = new _MenuOption2.default('C', 'Connect', 'Connect to selected network', this.connectToSelected.bind(this));
    this._menu = new _Menu2.default(_app2.default, [this._connectOption, new _MenuOption2.default('N', 'New', 'Create new connection', this.toNetworkSelection.bind(this))], false);

    const listData = this._getListData();
    if (!listData.length) {
      throw new Error('No recent connections found.');
    }

    const columns = [{
      heading: 'Network',
      width: 10
    }, {
      heading: 'Host',
      width: 30
    }, {
      heading: 'Authentication',
      width: 40
    }];

    this._list = new _List2.default(_app2.default, columns, listData, true, this._menu, true, this.onListSelect.bind(this));
  }

  async onListSelect() {
    this._menu.setSelectedOption(this._connectOption.key);
  }

  async toNetworkSelection() {
    _app2.default.replaceView(new _NetworkSelection2.default());
  }

  _getListData() {
    this._history = _Connection2.default.getHistory();
    return this._history.map(rec => [rec.network, `${rec.host}:${rec.port.toString()}`, rec.cookieFile || `${rec.user}:${'*'.repeat(rec.password.length)}`]);
  }

  async connectToSelected() {
    try {
      const selectedIndex = this._list.selectedRowIndex;
      const history = this._history[selectedIndex];
      const network = _Network2.default.fromString(history.network);
      const connection = new _Connection2.default(network);
      connection.host = history.host;
      connection.port = history.port;
      connection.cookieFile = history.cookieFile;
      connection.user = history.user;
      connection.password = history.password;
      _state2.default.connection = connection;
      await connection.connect();
      this._list.setData(this._getListData());
      _app2.default.pushView(new _MainMenu2.default());
    } catch (err) {
      _app2.default.setError(err.message);
    }
  }

  render() {
    // Render list first
    this._list.render();

    // Render menu last so cursor position is left in correct position
    this._menu.render(false);
  }

  async handle(key) {
    await this._menu.handle(key);
    await this._list.handle(key);
  }
}
exports.default = ConnectionHistory;