'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Network = require('cashlib/lib/Network');

var _Network2 = _interopRequireDefault(_Network);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuOption = require('tooey/lib/MenuOption');

var _MenuOption2 = _interopRequireDefault(_MenuOption);

var _Connection = require('../../model/Connection');

var _Connection2 = _interopRequireDefault(_Connection);

var _ConnectionSettings = require('./ConnectionSettings');

var _ConnectionSettings2 = _interopRequireDefault(_ConnectionSettings);

var _ConnectionHistory = require('./ConnectionHistory');

var _ConnectionHistory2 = _interopRequireDefault(_ConnectionHistory);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class NetworkSelection extends _ViewBase2.default {

  constructor() {
    super('Connect to node');

    // Build menu
    this._continueOption = new _MenuOption2.default('C', 'Continue', 'Connect to Network', this.toConnectionSettings.bind(this));
    const menuOptions = [this._continueOption, new _MenuOption2.default('R', 'Recent', 'Recent connections', this.toConnectionHistory.bind(this))];
    this._menu = new _Menu2.default(_app2.default, menuOptions, false);

    // Build networks list
    this._networks = [['mainnet'], ['testnet'], ['regtest'], ['nol']];
    this._list = new _List2.default(_app2.default, [{
      heading: 'Network',
      width: 25
    }], this._networks, false, undefined, true, this.onListSelect.bind(this));
  }

  async onListSelect() {
    this._menu.setSelectedOption(this._continueOption.key);
  }

  render() {
    // Render network list
    this._list.render();

    // Render menu last (for correct cursor positioning)
    this._menu.render(false);
  }

  get _selectedNetwork() {
    const selectedIndex = this._list.selectedRowIndex;
    return this._networks[selectedIndex][0];
  }

  async toConnectionSettings() {
    try {
      const networkLabel = this._selectedNetwork;
      if (networkLabel === 'mainnet') {
        // Disallow mainnet connections until we have resolved all of
        // the security issues (passwords are currently stored in plain text
        // and we will need to store private keys for tx signing). Also
        // immaturity of cashlib just creates to much risk.
        throw new Error('Sorry, mainnet connections are not secure/supported yet');
      }
      const network = _Network2.default.fromString(networkLabel);
      const connection = new _Connection2.default(network);
      _state2.default.connection = connection;
      _app2.default.pushView(new _ConnectionSettings2.default());
    } catch (err) {
      _app2.default.setError(err.message);
    }
  }

  async toConnectionHistory() {
    try {
      _app2.default.replaceView(new _ConnectionHistory2.default());
    } catch (err) {
      _app2.default.setError(err.message);
    }
  }

  async handle(key) {
    await this._menu.handle(key);
    await this._list.handle(key);
  }
}
exports.default = NetworkSelection;