'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _cliui = require('cliui');

var _cliui2 = _interopRequireDefault(_cliui);

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _output = require('tooey/lib/output');

var _output2 = _interopRequireDefault(_output);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Input = require('tooey/lib/Input');

var _Input2 = _interopRequireDefault(_Input);

var _InputHelp = require('tooey/lib/InputHelp');

var _InputHelp2 = _interopRequireDefault(_InputHelp);

var _keys = require('tooey/lib/keys');

var _GenericList = require('./GenericList');

var _GenericList2 = _interopRequireDefault(_GenericList);

var _GenericText = require('./GenericText');

var _GenericText2 = _interopRequireDefault(_GenericText);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class RawInput extends _ViewBase2.default {

  constructor() {
    super('Enter RPC command');
    this._historyLevel = 0;
    this._input = new _Input2.default(_app2.default, this.onEnter.bind(this));

    const inputHelpText = `${_InputHelp.DEFAULT_TEXT}; ${_colors2.default.bold('Up')} and ${_colors2.default.bold('Down')} for history`;
    this._inputHelp = new _InputHelp2.default(inputHelpText);
  }

  render() {
    // Render instruction text
    if (!this._input.value) {
      _output2.default.cursorTo(0, 5);
      const ui = (0, _cliui2.default)();
      ui.div({
        text: _colors2.default.gray('Enter an RPC command that will be sent to the bitcoin node. ' + 'E.g. enter \'help\' (without the quotes) to get a list of commands or \'help\' ' + 'followed by a command name to get help for that command.')
      });
      console.log(ui.toString());
    }

    this._inputHelp.render();

    // Render input last for correct cursor positioning
    this._input.render();
  }

  _loadEarlier() {
    if (this._historyLevel < _state2.default.rpc.history.length) {
      this._historyLevel++;
    }
    this._loadFromHistory();
  }

  _loadLater() {
    if (this._historyLevel > 1) {
      this._historyLevel--;
      this._loadFromHistory();
    } else {
      // History exhausted - clear input
      this._input.value = '';
    }
  }

  _loadFromHistory() {
    if (!_state2.default.rpc.history.length) {
      _app2.default.setWarning('No history found');
      return;
    }
    const index = _state2.default.rpc.history.length - this._historyLevel;
    this._input.value = _state2.default.rpc.history[index];
  }

  async handle(key) {
    switch (key) {
      case _keys.KEY_DOWN:
        this._loadLater();
        break;
      case _keys.KEY_UP:
        this._loadEarlier();
        break;
      default:
        await this._input.handle(key);
    }
  }

  async onEnter() {
    try {
      const rpcResult = await _state2.default.rpc.request(this._input.value, true);
      if (typeof rpcResult === 'string') {
        const outputLines = rpcResult.split('\n');
        if (outputLines.length > 1 || rpcResult.length < _output2.default.width) {
          _app2.default.pushView(new _GenericList2.default('RPC result', outputLines));
        } else {
          _app2.default.pushView(new _GenericText2.default('RPC result', rpcResult));
        }
      } else if (typeof rpcResult === 'number') {
        _app2.default.pushView(new _GenericText2.default('RPC result', rpcResult.toString()));
      } else if (typeof rpcResult === 'object') {
        const stringified = JSON.stringify(rpcResult, null, 2);
        const outputLines = stringified.split('\n');
        _app2.default.pushView(new _GenericList2.default('RPC result', outputLines));
      } else if (Array.isArray(rpcResult)) {
        const outputLines = rpcResult.map(entry => JSON.stringify(entry));
        _app2.default.pushView(new _GenericList2.default('RPC result', outputLines));
      } else {
        _app2.default.setError('Unexpected output received; don\'t know how to display');
        return;
      }
      this._input.value = '';
      this._historyLevel = 0;
    } catch (err) {
      let errorMessage;
      if (err.message.includes('ECONNREFUSED')) {
        errorMessage = 'Error: ECONNREFUSED (bitcoind possibly not running)';
      } else if (err.message.includes('401')) {
        errorMessage = 'Error: 401 (Not authorized)';
      } else {
        [errorMessage] = err.message.split('\n');
      }
      _app2.default.setError(errorMessage);
    }
  }
}
exports.default = RawInput;