'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Transaction = require('cashlib/lib/Transaction');

var _Transaction2 = _interopRequireDefault(_Transaction);

var _Output = require('cashlib/lib/Output');

var _Output2 = _interopRequireDefault(_Output);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TransactionOutputs extends _ViewBase2.default {

  constructor() {
    super('Transaction Outputs');
    this._menu = new _Menu2.default(_app2.default);

    const transaction = _state2.default.transactions.active;
    const outputs = transaction.outputs.map(TransactionOutputs._mapOutputToListRow);
    const columns = [{
      heading: 'Index',
      width: 8
    }, {
      heading: 'Value (BCH)',
      width: 15
    }, {
      heading: 'Address',
      width: 40
    }, {
      heading: 'Type',
      width: 10
    }];
    this._list = new _List2.default(_app2.default, columns, outputs, true, this._menu);
  }

  static _mapOutputToListRow(output, index) {
    const value = (output.value / 100000000).toFixed(8);
    let addressEncoded;
    try {
      const address = output.getAddress(_state2.default.connection.network);
      if (address) {
        addressEncoded = address.toString();
      }
    } catch (err) {
      _app2.default.setWarning(err.message);
    }
    if (!addressEncoded) {
      addressEncoded = 'Sorry, not available yet';
    }
    return [index.toString(), value, addressEncoded, output.scriptType];
  }

  render() {
    // Render outputs list
    this._list.render();

    // Render menu last for correct cursor positioning
    this._menu.render(false);
  }

  async handle(key) {
    await this._menu.handle(key);
    await this._list.handle(key);
  }
}
exports.default = TransactionOutputs;
// import Address from 'cashlib/lib/Address';