'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Transaction = require('cashlib/lib/Transaction');

var _Transaction2 = _interopRequireDefault(_Transaction);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuOption = require('tooey/lib/MenuOption');

var _MenuOption2 = _interopRequireDefault(_MenuOption);

var _output = require('tooey/lib/output');

var _output2 = _interopRequireDefault(_output);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TransactionRaw extends _ViewBase2.default {

  constructor() {
    super('Raw Transaction');
    // Break raw transaction into pages.  Note: we can't use List as when the output is copied
    // to the clipboard it will contain a linebreak char for each line.
    const data = [];
    const tx = _state2.default.transactions.active;
    const raw = tx.serialize();
    const charsPerPage = _output2.default.width * _output2.default.contentHeight;
    const numPages = Math.ceil(raw.length / charsPerPage);
    for (let x = 0; x < numPages; x++) {
      data.push(raw.substr(x * charsPerPage, charsPerPage));
    }

    const options = [];
    if (numPages) {
      options.push(new _MenuOption2.default('N', 'Next page', 'Go to next page', this.nextPage.bind(this)));
      options.push(new _MenuOption2.default('P', 'Previous page', 'Return to previous page', this.previousPage.bind(this)));
    }
    this._menu = new _Menu2.default(_app2.default, options, true);
    this._data = data;
    this._currentPage = 1;
    this._numPages = numPages;
  }

  render() {
    // Render raw transaction
    // Just output continuous string - don't use cliui as
    // even with wrapping we get linebreak chars in output
    // which get copied to the clipboard when user copies
    // text
    _output2.default.cursorTo(0, _output2.default.contentStartRow);
    console.log(this._data[this._currentPage - 1]);

    // Render menu last for correct cursor positioning
    this._menu.render(false);
  }

  async nextPage() {
    if (this._currentPage === this._numPages) {
      _app2.default.setInfo('No more pages');
    } else {
      this._currentPage += 1;
    }
  }

  async previousPage() {
    if (this._currentPage === 1) {
      _app2.default.setInfo('Already at start');
    } else {
      this._currentPage -= 1;
    }
  }

  async handle(key) {
    await this._menu.handle(key);
  }
}
exports.default = TransactionRaw;